noData property
String
get
noData
Shown in the centre of the grid when there are no data rows.
Implementation
String get noData;
Shown in the centre of the grid when there are no data rows.
String get noData;