TablexStrings class abstract
All user-visible strings used by the Tablex package.
Obtain an instance with tablexStrings. Implement this class to add a custom locale without forking the package:
class MyTablexStrings implements TablexStrings {
@override String get noData => 'Keine Daten';
// … implement every getter …
}
Constructors
- TablexStrings.of(TablexLocale locale)
-
Returns the implementation for
locale.factory
Properties
- apply → String
-
Label for the apply button in the filter dialog.
no setter
- cancel → String
-
Label for the cancel button in the filter dialog.
no setter
- clear → String
-
Label for the "clear selection" button in the selection summary bar.
no setter
- clearAll → String
-
Label for the "clear all active filters" button in the filter bar.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- manageColumns → String
-
Tooltip for the TablexColumnManagerButton.
no setter
- next → String
-
Tooltip for the next-page icon button.
no setter
- noData → String
-
Shown in the centre of the grid when there are no data rows.
no setter
- noResults → String
-
Shown instead of showing when
totalis 0.no setter - previous → String
-
Tooltip for the previous-page icon button.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
filterOperatorLabel(
String operatorKey) → String - Returns the localised label for a filter operator key.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
selected(
int count) → String - e.g. "5 selected"
-
showing(
int start, int end, int total) → String - e.g. "Showing 1–13 of 120"
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited